/*
	CDInputboxControl.m
	CocoaDialog
	Copyright (C) 2004 Mark A. Stratman <mark@sporkstorms.org>
 
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
 
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
 
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#import "CDInputboxControl.h"


@implementation CDInputboxControl

- (NSDictionary *) availableKeys
{
	NSNumber *vOne = [NSNumber numberWithInt:CDOptionsOneValue];
	
	return [NSDictionary dictionaryWithObjectsAndKeys:
		vOne, @"text",
		vOne, @"informative-text",
		vOne, @"button1",
		vOne, @"button2",
		vOne, @"button3",
		nil];
}

- (NSArray *) runControlFromOptions:(CDOptions *)options
{
	int rv;
	NSString *returnString = nil;

	[self setOptions:options];

	// check that they specified at least a button1
	// return nil if not
	if (![options optValue:@"button1"] 
	    && [self isMemberOfClass:[CDInputboxControl class]]) 
	{
		if ([options hasOpt:@"debug"]) {
			printf("ERROR: Must supply at least a --button1 "
			       "(ignore the following 'General error')\n");
		}
		return nil;
	}	
	
	// Load Inputbox.nib or return nil
	if (![NSBundle loadNibNamed:@"Inputbox" owner:self]) {
		if ([options hasOpt:@"debug"]) {
			printf("ERROR: could not load Inputbox.nib\n");
		}
		return nil;
	}

	// set informative text (label outlet)
	if ([options optValue:@"informative-text"]) {
		[label setStringValue:[options optValue:@"informative-text"]];
	} else {
		[label setStringValue:@""];
	}
	
	// Set initial text in textfield
	if ([options optValue:@"text"]) {
		[textField setStringValue:[options optValue:@"text"]];
	} else {
		[textField setStringValue:@""];
	}
	inputText = [[textField stringValue] retain];
	
	// set title
	if ([options optValue:@"title"] != nil) {
		[panel setTitle:[options optValue:@"title"]];
	}

	// set the buttons
	[self setButtons];
		
	// resize if necessary
	if ([self windowNeedsResize:panel]) {
		[panel setContentSize:[self findNewSizeForWindow:panel]];
	}
		
	// select all the text
	if ([options hasOpt:@"selected"]) {
		[textField selectText:self];
	}
	
	// Run modal
	rv = [NSApp runModalForWindow:panel];

	// set returnString
	if ([options hasOpt:@"string-output"]) {
		if (rv == 1) {
			returnString = [options optValue:@"button1"];
		} else if (rv == 2) {
			returnString = [options optValue:@"button2"];
		} else if (rv == 3) {
			returnString = [options optValue:@"button3"];
		}
	} else {
		returnString = [NSString stringWithFormat:@"%d",rv];
	}
	return [NSArray arrayWithObjects:returnString, inputText, nil];
}

- (void) setButtons
{
	CDOptions *options = [self options];
	[button1 setTitle:[options optValue:@"button1"]];
	if ([options optValue:@"button2"]) {
		[button2 setTitle:[options optValue:@"button2"]];
		if ([[options optValue:@"button2"] isEqualToString:@"Cancel"]) {
			[button2 setKeyEquivalent:@"\e"];
		}
		if ([options optValue:@"button3"]) {
			[button3 setTitle:[options optValue:@"button3"]];
			if ([[options optValue:@"button3"] isEqualToString:@"Cancel"]) {
				[button3 setKeyEquivalent:@"\e"];
			}
		} else {
			[button3 setEnabled:NO];
			[button3 setHidden:YES];
		}
	} else {
		[button2 setEnabled:NO];
		[button2 setHidden:YES];
		[button3 setEnabled:NO];
		[button3 setHidden:YES];
	}
}

- (IBAction) button1Pressed:(id)sender
{
	[NSApp stopModalWithCode:1];
}

- (IBAction) button2Pressed:(id)sender
{
	[NSApp stopModalWithCode:2];
}

- (IBAction) button3Pressed:(id)sender
{
	[NSApp stopModalWithCode:3];
}

- (void)controlTextDidChange:(NSNotification *)aNotification
{
	[inputText release];
	inputText = [[textField stringValue] retain];
}
- (void) dealloc
{
	[inputText release];
}

@end
