/*
	CDYesNoMsgboxControl.m
	CocoaDialog
	Copyright (C) 2004 Mark A. Stratman <mark@sporkstorms.org>
 
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
 
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
 
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#import "CDYesNoMsgboxControl.h"


@implementation CDYesNoMsgboxControl

- (NSDictionary *) availableKeys
{
	NSNumber *vOne = [NSNumber numberWithInt:CDOptionsOneValue];
	NSNumber *vNone = [NSNumber numberWithInt:CDOptionsNoValues];

	return [NSDictionary dictionaryWithObjectsAndKeys:
		vOne, @"text",
		vOne, @"informative-text",
		vOne, @"style",
		vNone, @"no-cancel",
		nil];
}

- (NSArray *) runControlFromOptions:(CDOptions *)options
{
	NSAlert *alert;
	int rv;
	NSString *returnString = nil;
	
	[self setOptions:options];
	
	alert = [[NSAlert alloc] init];

	[alert addButtonWithTitle:@"Yes"];
	[alert addButtonWithTitle:@"No"];
	if (![options hasOpt:@"no-cancel"]) {
		[alert addButtonWithTitle:@"Cancel"];
	}
	if ([options optValue:@"text"]) {
		[alert setMessageText:[options optValue:@"text"]];
	}
	if ([options optValue:@"informative-text"]) {
		[alert setInformativeText:[options optValue:@"informative-text"]];
	}
	if ([options hasOpt:@"style"]) { 
		if ([[options optValue:@"style"] isCaseInsensitiveLike:@"warning"]) {
			[alert setAlertStyle:NSWarningAlertStyle];
		} else if ([[options optValue:@"style"] isCaseInsensitiveLike:@"critical"]) {
			[alert setAlertStyle:NSCriticalAlertStyle];
		} else {
			[alert setAlertStyle:NSInformationalAlertStyle];
		}
	} else {
		[alert setAlertStyle:NSInformationalAlertStyle];
	}

	if ([options optValue:@"title"] != nil) {
		[[alert window] setTitle:[options optValue:@"title"]];
	}
		
	/*
	if ([self windowNeedsResize:[alert window]]) {
		[[alert window] setContentSize:[self findNewSizeForWindow:[alert window]]];
	}
	 */
	
	rv = [alert runModal];

	if ([options hasOpt:@"string-output"]) {
		if (rv == NSAlertFirstButtonReturn) {
			returnString = @"Yes";
		} else if (rv == NSAlertSecondButtonReturn) {
			returnString = @"No";
		} else if (rv == NSAlertThirdButtonReturn) {
			returnString = @"Cancel";
		}
	} else {
		if (rv == NSAlertFirstButtonReturn) {
			returnString = @"1";
		} else if (rv == NSAlertSecondButtonReturn) {
			returnString = @"2";
		} else if (rv == NSAlertThirdButtonReturn) {
			returnString = @"3";
		}
	}
	if (returnString == nil) {
		returnString = @"";
	}
	[alert release];
	return [NSArray arrayWithObject:returnString];
}


@end
